@@ -1,10 +1,10 @@
 package Perinci::Sub::XCompletion;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-01-15'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 1;
-# ABSTRACT: Write completion routines in x.{element_,}completion attributes
+# ABSTRACT: Write completion routines in x.{,element_,index_}completion attributes
 
 __END__
 
@@ -14,11 +14,11 @@ __END__
 
 =head1 NAME
 
-Perinci::Sub::XCompletion - Write completion routines in x.{element_,}completion attributes
+Perinci::Sub::XCompletion - Write completion routines in x.{,element_,index_}completion attributes
 
 =head1 VERSION
 
-This document describes version 0.06 of Perinci::Sub::XCompletion (from Perl distribution Perinci-Sub-XCompletion), released on 2016-07-22.
+This document describes version 0.07 of Perinci::Sub::XCompletion (from Perl distribution Perinci-Sub-XCompletion), released on 2017-01-15.
 
 =head1 SYNOPSIS
 
@@ -37,9 +37,12 @@ In L<Rinci> metadata:
 
 This is a module to support an experimental (and temporary?) way to ease writing
 completion routine. Instead of putting a coderef in C<completion> or
-C<element_completion> property in argument specification, you put C<< [$name,
-\%args] >> in C<x.completion> or C<x.element_completion> attributes. C<$name> is
-the name of submodule to use, and \%args is arguments.
+C<element_completion> property in argument specification, you put C<$name> or
+C<< [$name, \%args] >> in C<x.completion> or C<x.element_completion> or
+C<x.index_completion> attributes. C<$name> is the name of
+C<Perinci::Sub::XCompletion::*> submodule to use, and \%args is arguments.
+
+But you can also use a coderef as usual.
 
 =head1 HOMEPAGE
 
@@ -67,7 +70,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
